==> jc-1.4.0.tar.gz: javax/swing/text/DefaultHighlighter__24HighlightEntry.h <==
// class javax.swing.text.DefaultHighlighter$HighlightEntry

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class e5be2279e31369a7 javax_swing_text_DefaultHighlighter__24HighlightEntry

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_text_DefaultHighlighter__24HighlightEntry_H_
#define _JC_javax_swing_text_DefaultHighlighter__24HighlightEntry_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_text_DefaultHighlighter$object;
struct _jc_javax_swing_text_Highlighter__24HighlightPainter$object;

// Typedefs
typedef struct _jc_javax_swing_text_DefaultHighlighter__24HighlightEntry$sub_refs	_jc_javax_swing_text_DefaultHighlighter__24HighlightEntry$sub_refs;
typedef struct _jc_javax_swing_text_DefaultHighlighter__24HighlightEntry$sub_nonrefs	_jc_javax_swing_text_DefaultHighlighter__24HighlightEntry$sub_nonrefs;
typedef struct _jc_javax_swing_text_DefaultHighlighter__24HighlightEntry$refs	_jc_javax_swing_text_DefaultHighlighter__24HighlightEntry$refs;
typedef struct _jc_javax_swing_text_DefaultHighlighter__24HighlightEntry$nonrefs	_jc_javax_swing_text_DefaultHighlighter__24HighlightEntry$nonrefs;
typedef struct _jc_javax_swing_text_DefaultHighlighter__24HighlightEntry$object	_jc_javax_swing_text_DefaultHighlighter__24HighlightEntry$object;

typedef const struct _jc_javax_swing_text_DefaultHighlighter__24HighlightEntry$vmethods	_jc_javax_swing_text_DefaultHighlighter__24HighlightEntry$vmethods;
typedef const struct _jc_javax_swing_text_DefaultHighlighter__24HighlightEntry$vtable	_jc_javax_swing_text_DefaultHighlighter__24HighlightEntry$vtable;
typedef const struct _jc_javax_swing_text_DefaultHighlighter__24HighlightEntry$vtype	_jc_javax_swing_text_DefaultHighlighter__24HighlightEntry$vtype;

// Constructors
extern void _jc_javax_swing_text_DefaultHighlighter__24HighlightEntry$method$_init$bd9a7518b10a2433(_jc_env *, struct _jc_javax_swing_text_DefaultHighlighter__24HighlightEntry$object *, struct _jc_javax_swing_text_DefaultHighlighter$object *, jint, jint, struct _jc_object *);

// Virtual methods
extern jint _jc_javax_swing_text_DefaultHighlighter__24HighlightEntry$method$getEndPosition$c5ec883b216e3fa4(_jc_env *, struct _jc_javax_swing_text_DefaultHighlighter__24HighlightEntry$object *);
extern struct _jc_object *_jc_javax_swing_text_DefaultHighlighter__24HighlightEntry$method$getPainter$226d1092af492f1e(_jc_env *, struct _jc_javax_swing_text_DefaultHighlighter__24HighlightEntry$object *);
extern jint _jc_javax_swing_text_DefaultHighlighter__24HighlightEntry$method$getStartPosition$1ff94339ac25212b(_jc_env *, struct _jc_javax_swing_text_DefaultHighlighter__24HighlightEntry$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_text_DefaultHighlighter__24HighlightEntry$method_info$getEndPosition$c5ec883b216e3fa4;
extern _jc_method _jc_javax_swing_text_DefaultHighlighter__24HighlightEntry$method_info$getPainter$226d1092af492f1e;
extern _jc_method _jc_javax_swing_text_DefaultHighlighter__24HighlightEntry$method_info$getStartPosition$1ff94339ac25212b;

// Virtual methods structure
struct _jc_javax_swing_text_DefaultHighlighter__24HighlightEntry$vmethods {
	jint	(*getEndPosition$c5ec883b216e3fa4)(_jc_env *, struct _jc_javax_swing_text_DefaultHighlighter__24HighlightEntry$object *);
	struct _jc_object	*(*getPainter$226d1092af492f1e)(_jc_env *, struct _jc_javax_swing_text_DefaultHighlighter__24HighlightEntry$object *);
	jint	(*getStartPosition$1ff94339ac25212b)(_jc_env *, struct _jc_javax_swing_text_DefaultHighlighter__24HighlightEntry$object *);
};

// Vtable
struct _jc_javax_swing_text_DefaultHighlighter__24HighlightEntry$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_text_DefaultHighlighter__24HighlightEntry$vmethods	javax_swing_text_DefaultHighlighter__24HighlightEntry;
};

// Vtype
struct _jc_javax_swing_text_DefaultHighlighter__24HighlightEntry$vtype {
	_jc_type			type;
	_jc_javax_swing_text_DefaultHighlighter__24HighlightEntry$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_text_DefaultHighlighter__24HighlightEntry$sub_refs {
	struct _jc_object	*painter;
	struct _jc_javax_swing_text_DefaultHighlighter$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_text_DefaultHighlighter__24HighlightEntry$refs {
    _jc_javax_swing_text_DefaultHighlighter__24HighlightEntry$sub_refs	javax_swing_text_DefaultHighlighter__24HighlightEntry;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_text_DefaultHighlighter__24HighlightEntry$sub_nonrefs {
	jint	p0;
	jint	p1;
};

// Non-reference instance fields (object)
struct _jc_javax_swing_text_DefaultHighlighter__24HighlightEntry$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_text_DefaultHighlighter__24HighlightEntry$sub_nonrefs	javax_swing_text_DefaultHighlighter__24HighlightEntry;
};

// Object instance structure
struct _jc_javax_swing_text_DefaultHighlighter__24HighlightEntry$object {
	_jc_javax_swing_text_DefaultHighlighter__24HighlightEntry$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_text_DefaultHighlighter__24HighlightEntry$vtype	*vtype;
	_jc_javax_swing_text_DefaultHighlighter__24HighlightEntry$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_text_DefaultHighlighter__24HighlightEntry$vtype _jc_javax_swing_text_DefaultHighlighter__24HighlightEntry$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_text_DefaultHighlighter__24HighlightEntry, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_text_DefaultHighlighter__24HighlightEntry$class_object;

#endif	/* _JC_javax_swing_text_DefaultHighlighter__24HighlightEntry_H_ */

==> jc-1.4.6.tar.gz: javax/swing/text/DefaultHighlighter__24HighlightEntry.h <==
// class javax.swing.text.DefaultHighlighter$HighlightEntry

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class e5be2279e31369a7 javax_swing_text_DefaultHighlighter__24HighlightEntry

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_text_DefaultHighlighter__24HighlightEntry_H_
#define _JC_javax_swing_text_DefaultHighlighter__24HighlightEntry_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_text_DefaultHighlighter$object;
struct _jc_javax_swing_text_Highlighter__24HighlightPainter$object;

// Typedefs
typedef struct _jc_javax_swing_text_DefaultHighlighter__24HighlightEntry$sub_refs	_jc_javax_swing_text_DefaultHighlighter__24HighlightEntry$sub_refs;
typedef struct _jc_javax_swing_text_DefaultHighlighter__24HighlightEntry$sub_nonrefs	_jc_javax_swing_text_DefaultHighlighter__24HighlightEntry$sub_nonrefs;
typedef struct _jc_javax_swing_text_DefaultHighlighter__24HighlightEntry$refs	_jc_javax_swing_text_DefaultHighlighter__24HighlightEntry$refs;
typedef struct _jc_javax_swing_text_DefaultHighlighter__24HighlightEntry$nonrefs	_jc_javax_swing_text_DefaultHighlighter__24HighlightEntry$nonrefs;
typedef struct _jc_javax_swing_text_DefaultHighlighter__24HighlightEntry$object	_jc_javax_swing_text_DefaultHighlighter__24HighlightEntry$object;

typedef const struct _jc_javax_swing_text_DefaultHighlighter__24HighlightEntry$vmethods	_jc_javax_swing_text_DefaultHighlighter__24HighlightEntry$vmethods;
typedef const struct _jc_javax_swing_text_DefaultHighlighter__24HighlightEntry$vtable	_jc_javax_swing_text_DefaultHighlighter__24HighlightEntry$vtable;
typedef const struct _jc_javax_swing_text_DefaultHighlighter__24HighlightEntry$vtype	_jc_javax_swing_text_DefaultHighlighter__24HighlightEntry$vtype;

// Constructors
extern void _jc_javax_swing_text_DefaultHighlighter__24HighlightEntry$method$_init$bd9a7518b10a2433(_jc_env *, struct _jc_javax_swing_text_DefaultHighlighter__24HighlightEntry$object *, struct _jc_javax_swing_text_DefaultHighlighter$object *, jint, jint, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_javax_swing_text_DefaultHighlighter__24HighlightEntry$method$getEndPosition$c5ec883b216e3fa4(_jc_env *, struct _jc_javax_swing_text_DefaultHighlighter__24HighlightEntry$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_javax_swing_text_DefaultHighlighter__24HighlightEntry$method$getPainter$226d1092af492f1e(_jc_env *, struct _jc_javax_swing_text_DefaultHighlighter__24HighlightEntry$object *) _JC_JCNI_ATTR;
extern jint _jc_javax_swing_text_DefaultHighlighter__24HighlightEntry$method$getStartPosition$1ff94339ac25212b(_jc_env *, struct _jc_javax_swing_text_DefaultHighlighter__24HighlightEntry$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_text_DefaultHighlighter__24HighlightEntry$method_info$getEndPosition$c5ec883b216e3fa4;
extern _jc_method _jc_javax_swing_text_DefaultHighlighter__24HighlightEntry$method_info$getPainter$226d1092af492f1e;
extern _jc_method _jc_javax_swing_text_DefaultHighlighter__24HighlightEntry$method_info$getStartPosition$1ff94339ac25212b;

// Virtual methods structure
struct _jc_javax_swing_text_DefaultHighlighter__24HighlightEntry$vmethods {
	jint	(*getEndPosition$c5ec883b216e3fa4)(_jc_env *, struct _jc_javax_swing_text_DefaultHighlighter__24HighlightEntry$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getPainter$226d1092af492f1e)(_jc_env *, struct _jc_javax_swing_text_DefaultHighlighter__24HighlightEntry$object *) _JC_JCNI_ATTR;
	jint	(*getStartPosition$1ff94339ac25212b)(_jc_env *, struct _jc_javax_swing_text_DefaultHighlighter__24HighlightEntry$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_text_DefaultHighlighter__24HighlightEntry$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_text_DefaultHighlighter__24HighlightEntry$vmethods	javax_swing_text_DefaultHighlighter__24HighlightEntry;
};

// Vtype
struct _jc_javax_swing_text_DefaultHighlighter__24HighlightEntry$vtype {
	_jc_type			type;
	_jc_javax_swing_text_DefaultHighlighter__24HighlightEntry$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_text_DefaultHighlighter__24HighlightEntry$sub_refs {
	struct _jc_object	*painter;
	struct _jc_javax_swing_text_DefaultHighlighter$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_text_DefaultHighlighter__24HighlightEntry$refs {
    _jc_javax_swing_text_DefaultHighlighter__24HighlightEntry$sub_refs	javax_swing_text_DefaultHighlighter__24HighlightEntry;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_text_DefaultHighlighter__24HighlightEntry$sub_nonrefs {
	jint	p0;
	jint	p1;
};

// Non-reference instance fields (object)
struct _jc_javax_swing_text_DefaultHighlighter__24HighlightEntry$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_text_DefaultHighlighter__24HighlightEntry$sub_nonrefs	javax_swing_text_DefaultHighlighter__24HighlightEntry;
};

// Object instance structure
struct _jc_javax_swing_text_DefaultHighlighter__24HighlightEntry$object {
	_jc_javax_swing_text_DefaultHighlighter__24HighlightEntry$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_text_DefaultHighlighter__24HighlightEntry$vtype	*vtype;
	_jc_javax_swing_text_DefaultHighlighter__24HighlightEntry$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_text_DefaultHighlighter__24HighlightEntry$vtype _jc_javax_swing_text_DefaultHighlighter__24HighlightEntry$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_text_DefaultHighlighter__24HighlightEntry, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_text_DefaultHighlighter__24HighlightEntry$class_object;

#endif	/* _JC_javax_swing_text_DefaultHighlighter__24HighlightEntry_H_ */
